@@ -77,7 +77,7 @@ def move_active_window_to_position_on_gnome(screen_geometry):
     It only works on Gnome Shell.
     """
     if not HAVE_QTDBUS:
-        raise TypeError("QtDBus should not be called on non Linux systems!")
+        raise TypeError("QtDBus should only be called on Linux systems!")
 
     JS_CODE = f"""
     const GLib = imports.gi.GLib;
@@ -109,7 +109,7 @@ def move_active_window_to_position_on_gnome(screen_geometry):
             logger.error("Failed move Window!")
             logger.error(x.errorMessage())
     else:
-        logger.error("Invalid dbus interface")
+        logger.warning("Invalid dbus interface on Gnome")
 
 
 def move_active_window_to_position_on_kde(screen_geometry):
@@ -119,7 +119,7 @@ def move_active_window_to_position_on_kde(screen_geometry):
     It only works on KDE.
     """
     if not HAVE_QTDBUS:
-        raise TypeError("QtDBus should not be called on non Linux systems!")
+        raise TypeError("QtDBus should only be called on Linux systems!")
 
     JS_CODE = f"""
     client = workspace.activeClient;
@@ -130,9 +130,8 @@ def move_active_window_to_position_on_kde(screen_geometry):
         "height": {screen_geometry.height}
     }};
     """
-    script_file = tempfile.NamedTemporaryFile(delete=False, suffix=".js")
-    script_file.write(JS_CODE.encode())
-    script_file.close()
+    with tempfile.NamedTemporaryFile(delete=False, suffix=".js") as script_file:
+        script_file.write(JS_CODE.encode())
 
     bus = QtDBus.QDBusConnection.sessionBus()
     if not bus.isConnected():
@@ -142,6 +141,7 @@ def move_active_window_to_position_on_kde(screen_geometry):
     interface = "org.kde.kwin.Scripting"
     path = "/Scripting"
     shell_interface = QtDBus.QDBusInterface(item, path, interface, bus)
+    # FIXME: shell_interface is not valid on latest KDE in Fedora 36.
     if shell_interface.isValid():
         x = shell_interface.call("loadScript", script_file.name)
         y = shell_interface.call("start")
@@ -149,7 +149,7 @@ def move_active_window_to_position_on_kde(screen_geometry):
             logger.error("Failed move Window!")
             logger.error(x.errorMessage(), y.errorMessage())
     else:
-        logger.error("Invalid dbus interface")
+        logger.warning("Invalid dbus interface on KDE")
 
     os.unlink(script_file.name)
 
@@ -180,10 +180,10 @@ def hook_exceptions(exc_type, exc_value, exc_traceback):
             "v",
         ]
         redacted = "REDACTED"
-        for func_name, func_vars in local_vars.items():
+        for func_vars in local_vars.values():
             for f in filter_vars:
                 if f in func_vars:
-                    local_vars[func_name][f] = redacted
+                    func_vars[f] = redacted
             for k, v in func_vars.items():
                 if isinstance(v, Capture):
                     func_vars[k].ocr_text = redacted
@@ -218,7 +218,7 @@ def hook_exceptions(exc_type, exc_value, exc_traceback):
         )
         print(message, file=sys.stderr)
 
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         logger.critical(
             "Uncaught exception! Quitting NormCap! (debug output limited)",
             exc_info=(exc_type, exc_value, exc_traceback),
@@ -228,7 +228,7 @@ def hook_exceptions(exc_type, exc_value, exc_traceback):
     sys.exit(1)
 
 
-@functools.lru_cache(maxsize=None)
+@functools.cache
 def get_icon(icon_file: str, system_icon: Optional[str] = None) -> QtGui.QIcon:
     """Load icon from system or if not available from resources."""
     if system_icon and QtGui.QIcon.hasThemeIcon(system_icon):
@@ -264,21 +264,3 @@ def copy_tessdata_files_to_config_dir():
     tessdata_path.mkdir(parents=True, exist_ok=True)
     for f in traineddata_files + doc_files:
         shutil.copy(f, tessdata_path / f.name)
-
-
-def copy_to_clipboard():
-    """Initialize a wrapper around qt clipboard.
-
-    Necesessary to avoid some wired results on Wayland, where text sometimes get
-    copied, and sometimes not.
-    """
-    from PySide6 import QtWidgets  # pylint: disable=all
-
-    app = QtWidgets.QApplication.instance() or QtWidgets.QApplication()
-
-    def copy_qt(text):
-        logger.debug("Copy to clipboard:\n%s", text)
-        cb = app.clipboard()
-        cb.setText(text)
-
-    return copy_qt
